@@ -326,10 +326,14 @@ class Model(object):
                 query = f"SELECT json_agg(json_build_object({', '.join(rel_fields)})) "
             query += f"FROM {rel.table_full_name(value.prefix)} "
             if '->' in value.key:
+                if isinstance(parent, Relationship) or isinstance(parent, Relationships):
+                    parent_table_alias = parent.relation.table_short_name(parent.prefix)
+                else:
+                    parent_table_alias = parent.table_short_name(main_prefix)
                 combined_key = value.key.split('->')
                 query += f"WHERE {rel.table_short_name(value.prefix)}.{value.field} = " \
                          f"(SELECT {combined_key[2]} FROM {combined_key[1]} " \
-                         f"WHERE id = {parent.relation.table_short_name(parent.prefix)}.{combined_key[0]})"
+                         f"WHERE id = {parent_table_alias}.{combined_key[0]})"
             else:
                 query += f"WHERE {rel.table_short_name(value.prefix)}.{value.field} = " \
                          f"{cls.table_short_name(main_prefix)}.{value.key}"
@@ -420,7 +424,7 @@ class Model(object):
     @classmethod
     def _generate_sql(cls):
         fields = cls.sql_fields()
-        f, parameters = cls.process_relationships()
+        f, parameters = cls.process_relationships(parent=cls)
         for attribute in cls.attributes():
             value = getattr(cls, attribute)
             if isinstance(value, QueryField) and value.parameters:
@@ -549,7 +553,7 @@ class Model(object):
         self.id = record_id.get('id')
 
     async def update(self):
-        if self.TABLE_NAME:
+        if not self.TABLE_NAME:
             raise ValueError(f"There is no TABLE_NAME attribute in class {self.__name__}")
 
         self.modified = datetime.datetime.utcnow()
